

set -ex



test ! -f ${PREFIX}/include/reproc/run.h
test ! -f ${PREFIX}/lib/libreproc${SHLIB_EXT}
test ! -f ${PREFIX}/lib/cmake/reproc/reproc-config-version.cmake
test -f ${PREFIX}/lib/libreproc.a
exit 0
